#!/usr/bin/perl -w
#########################################################################
#
# Serz Minus (Sergey Lepenkov), <abalama@cpan.org>
#
# Copyright (C) 1998-2021 D&D Corporation. All Rights Reserved
#
# This is free software; you can redistribute it and/or modify it
# under the same terms as Perl itself.
#
# $Id: 02-client.t 248 2021-11-16 17:26:22Z minus $
#
#########################################################################
use Test::More;
use R2D2Bot::Client;
use CTK::ConfGenUtil;

use constant {
    API_TOKEN   => $ENV{API_TOKEN} || "1234567890:AAF0FJgBjxf8N7p1lanxNaibtGjCm0K763Q",
    CHAT_ID     => $ENV{CHAT_ID} || 1234567890,
};

plan skip_all => "Currently a developer-only test" unless -d '.svn' || -d ".git";

# Create the instance
my $client = R2D2Bot::Client->new(
    token               => API_TOKEN,
    max_redirects       => 2,
    connect_timeout     => 12,
    inactivity_timeout  => 12,
    request_timeout     => 12,
    insecure            => 1, # IO::Socket::SSL::set_defaults(SSL_verify_mode => 0); # Skip verify for test only!
    #url_mask           => "http://ifconfig.io",
    #proxy               => 'socks://socks:socks@192.168.201.133:1080',
);
plan skip_all => sprintf("Can't initialize the client: %s", $client->error) unless $client->check;
note $client->status ? explain($client->res->json) : $client->trace;
#note explain hash($client->res->json, "result");
#note explain $client->res->content;
#note $client->request(GET => "getMe");

# Start testing
plan tests => 2;

# sendMessage
{
    my $status = $client->sendMessage(
        chat_id => CHAT_ID,
        text    => 'Hello world!',
    );
    ok($status, "Send message to chat")
        or diag($client->error); # diag($client->res->json("/description") || $client->res->message);
    note $status ? explain $client->res->json : $client->trace;
    #note $client->res->body;
}

# sendPhoto
{
    my $status = $client->sendPhoto(
        chat_id => CHAT_ID,
        photo   => {
            file => './src/img/droid.png',
        },
        caption => 'Look at my cool photo!'
    );
    ok($status, "Send photo to chat")
        or diag($client->error);
    note $status ? explain $client->res->json : $client->trace;
}

1;

__END__

